Name:           k3d
Version:        0.8.0.6
Release:        4%{?dist}
Summary:        A 3D Modeling, Animation and Rendering System

Group:          Applications/Multimedia
License:        GPLv2+
URL:            http://www.k-3d.org/
# Github URLs suck (tarball is called k3d, content uses k3d-k3d)
Source0:        https://github.com/K-3D/k3d/archive/k3d-%{version}/k3d-%{version}.tar.gz
Source1:        k3d.desktop

Patch1: 0001-k3d-0.8.0.2-cmake.diff.patch
Patch2: 0002-Suppress-Wnarrow-warnings.patch
Patch3: 0003-Fix-permissions.patch
Patch4: 0004-Avoid-signed-unsigned-int-warning.patch
Patch5: 0005-Work-around-gtkmm-gdkmm-glibmm-incompatibility.patch
# https://github.com/K-3D/k3d/pull/27
Patch6: 0006-Add-required-header-for-ostream-operations.patch

# This list is alpha sorted.
BuildRequires:  asciidoc
BuildRequires:  boost-devel
BuildRequires:  bzip2-devel
BuildRequires:  cairomm-devel
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  expat-devel
BuildRequires:  freetype-devel
BuildRequires:  ftgl-devel
BuildRequires:  glew-devel
BuildRequires:  gnome-vfs2-devel
BuildRequires:  gtkglext-devel
BuildRequires:  gtkmm24-devel
BuildRequires:  gts-devel
BuildRequires:  ImageMagick-c++-devel
BuildRequires:  libtiff-devel
BuildRequires:  libtool doxygen gettext
BuildRequires:  mesa-libGL-devel
BuildRequires:  OpenEXR-devel
BuildRequires:  pkgconfig(uuid)
BuildRequires:  plib-devel
BuildRequires:  python-devel

# Text widget uses bitstream font by default
BuildRequires: /usr/share/fonts/bitstream-vera/Vera.ttf
BuildRequires: /usr/share/fonts/bitstream-vera/VeraBI.ttf
BuildRequires: /usr/share/fonts/bitstream-vera/VeraBd.ttf
BuildRequires: /usr/share/fonts/bitstream-vera/VeraIt.ttf
BuildRequires: /usr/share/fonts/bitstream-vera/VeraMoBI.ttf
BuildRequires: /usr/share/fonts/bitstream-vera/VeraMoBd.ttf
BuildRequires: /usr/share/fonts/bitstream-vera/VeraMoIt.ttf
BuildRequires: /usr/share/fonts/bitstream-vera/VeraMono.ttf
BuildRequires: /usr/share/fonts/bitstream-vera/VeraSe.ttf
BuildRequires: /usr/share/fonts/bitstream-vera/VeraSeBd.ttf

Requires:       aqsis

# Text widget uses bitstream font by default
Requires: /usr/share/fonts/bitstream-vera/Vera.ttf
Requires: /usr/share/fonts/bitstream-vera/VeraBI.ttf
Requires: /usr/share/fonts/bitstream-vera/VeraBd.ttf
Requires: /usr/share/fonts/bitstream-vera/VeraIt.ttf
Requires: /usr/share/fonts/bitstream-vera/VeraMoBI.ttf
Requires: /usr/share/fonts/bitstream-vera/VeraMoBd.ttf
Requires: /usr/share/fonts/bitstream-vera/VeraMoIt.ttf
Requires: /usr/share/fonts/bitstream-vera/VeraMono.ttf
Requires: /usr/share/fonts/bitstream-vera/VeraSe.ttf
Requires: /usr/share/fonts/bitstream-vera/VeraSeBd.ttf

Requires(post):   /sbin/ldconfig
Requires(post):   desktop-file-utils
Requires(postun): /sbin/ldconfig
Requires(postun): desktop-file-utils

%description
K-3D is a complete 3D modeling, animation and rendering system. K-3D
features a robust, object oriented plugin architecture, designed to
scale to the needs of professional artists. It is designed from the
ground up to generate motion picture quality animation using RenderMan
compliant render engines.


%package devel
Summary:        Headers for rendering models written by K-3D
Group:          Development/Libraries
Requires:       %{name} = %{version}-%{release}


%description devel
This package contains the libraries and header files needed for
rendering a model written by K-3D.


%prep
%setup -q -n k3d-k3d-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1

%build
mkdir BUILD
cd BUILD
%cmake -Wno-dev ..
# Since our cmake macro disables rpath, we need to set some temp
# library paths as the build invokes some built binaries to generate
# proxy files.
export LD_LIBRARY_PATH=%{_builddir}/k3d-k3d-%{version}/BUILD/%{_lib}
make VERBOSE=1 %{?_smp_mflags}
cd ..

%install
cd BUILD
make install DESTDIR=$RPM_BUILD_ROOT
cd ..

# FIXME: Use Fedora-shipped fonts
for f in $RPM_BUILD_ROOT%{_datadir}/k3d/fonts/Vera*.ttf; do
b=$(basename "$f"); rm -f "$f"
ln -s /usr/share/fonts/bitstream-vera/$b "$f";
done

find $RPM_BUILD_ROOT -type f -name "*.la" -exec rm -f {} ';'

desktop-file-install \
    --dir $RPM_BUILD_ROOT%{_datadir}/applications  \
    %{SOURCE1}

# Register as an application to be visible in the software center
#
# NOTE: It would be *awesome* if this file was maintained by the upstream
# project, translated and installed into the right place during `make install`.
#
# See http://www.freedesktop.org/software/appstream/docs/ for more details.
#
mkdir -p $RPM_BUILD_ROOT%{_datadir}/appdata
cat > $RPM_BUILD_ROOT%{_datadir}/appdata/%{name}.appdata.xml <<EOF
<?xml version="1.0" encoding="UTF-8"?>
<!-- Copyright 2014 Richard Hughes <richard@hughsie.com> -->
<!--
EmailAddress: k3d-development@lists.sourceforge.net
SentUpstream: 2014-05-22
-->
<application>
  <id type="desktop">k3d.desktop</id>
  <metadata_license>CC0-1.0</metadata_license>
  <project_license>GPL-2.0+</project_license>
  <description>
    <p>
     K-3D is free-as-in-freedom 3D modeling and animation software.
     It combines flexible plugins with a visualization pipeline
     architecture, making K-3D a versatile and powerful tool for artists.
    </p>
    <p>
     K-3D's interface uses your platform's look-and-feel, and it's
     consistent with the applications you already know.
     New artists will find K-3D easy to understand, and professionals
     feel right at home. K-3D is intuitive, consistent, and discoverable.
    </p>
  </description>
  <screenshots>
    <screenshot type="default">http://www.k-3d.org/k3d_wiki/images/c/c2/Happy_buddha.png</screenshot>
  </screenshots>
  <url type="homepage">http://www.k-3d.org/</url>
</application>
EOF

%check
# FIXME: This doesn't work.
ctest


%post
/sbin/ldconfig
update-desktop-database %{_datadir}/applications > /dev/null 2>&1 || :


%postun
/sbin/ldconfig
update-desktop-database %{_datadir}/applications > /dev/null 2>&1 || :

%files
%doc AUTHORS README
%license COPYING
%{_bindir}/k3d*
%dir %{_libdir}/k3d
%{_libdir}/k3d/plugins
%{_libdir}/*.so.*
%dir %{_datadir}/k3d
%{_datadir}/k3d/*.k3d
%{_datadir}/k3d/documents
%{_datadir}/k3d/geometry
%{_datadir}/k3d/fonts
%{_datadir}/k3d/icons
%{_datadir}/k3d/locale
%{_datadir}/k3d/logo
%{_datadir}/k3d/lsystem
%{_datadir}/k3d/ngui
%{_datadir}/k3d/scripts
%dir %{_datadir}/k3d/shaders
%{_datadir}/k3d/shaders/displacement
%{_datadir}/k3d/shaders/glsl
%{_datadir}/k3d/shaders/imager
%{_datadir}/k3d/shaders/light
%{_datadir}/k3d/shaders/surface
%{_datadir}/k3d/shaders/volume
%{_datadir}/k3d/textures
%{_datadir}/k3d/guide
%{_datadir}/k3d/qtui
%{_mandir}/man1/k3d*
%{_datadir}/appdata/*.appdata.xml
%{_datadir}/applications/*.desktop

%files devel
%{_includedir}/k3d
%{_libdir}/k3d/include
%{_libdir}/*.so
%{_datadir}/k3d/shaders/*.h


%changelog
* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.0.6-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Feb 01 2017 Jonathan Wakely <jwakely@redhat.com> - 0.8.0.6-3
- Rebuilt for Boost 1.63 and patched for GCC 7

* Tue Jan 10 2017 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.8.0.6-2
- Rebuild for glew-2.0.0.

* Fri Oct 07 2016 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.8.0.6-1
- Update to 0.8.0.6.
- Add 0005-Work-around-gtkmm-gdkmm-glibmm-incompatibility.patch
  (F25FTBFS, F26FTBFS).
- Spec file massaging.

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.0.5-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sat Jan 16 2016 Jonathan Wakely <jwakely@redhat.com> - 0.8.0.5-3
- Rebuilt for Boost 1.60

* Fri Jan 15 2016 Adam Jackson <ajax@redhat.com> 0.8.0.5-2
- Rebuild for glew 1.13

* Fri Dec 11 2015 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.8.0.5-1
- Update to 0.8.0.5.
- Rebase patches.
- Introduce %%license.

* Thu Aug 27 2015 Jonathan Wakely <jwakely@redhat.com> - 0.8.0.3-8
- Rebuilt for Boost 1.59

* Wed Jul 29 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.0.3-7
- Rebuilt for https://fedoraproject.org/wiki/Changes/F23Boost159

* Wed Jul 22 2015 David Tardon <dtardon@redhat.com> - 0.8.0.3-6
- rebuild for Boost 1.58

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.0.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 0.8.0.3-4
- Rebuilt for GCC 5 C++11 ABI change

* Thu Mar 26 2015 Richard Hughes <rhughes@redhat.com> - 0.8.0.3-3
- Add an AppData file for the software center

* Thu Mar 12 2015 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.8.0.3-2
- Rebuild for GCC-5.0 C++-breakage.

* Fri Feb 06 2015 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.8.0.3-1
- Update to 0.8.0.3.
- Rework patches.

* Thu Jan 29 2015 Petr Machata <pmachata@redhat.com> - 0.8.0.2-32
- Rebuild for boost 1.57.0
- Drop use of boost/math/tools/test.hpp, which is not shipped anymore
  (k3d-0.8.0.2-boost157.patch)

* Wed Nov 26 2014 Rex Dieter <rdieter@fedoraproject.org> 0.8.0.2-31
- rebuild (openexr)

* Thu Sep 11 2014 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.8.0.2-30
- Add k3d-0.8.0.2-inotify.patch (RHBZ#1140146).

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.0.2-29
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.0.2-28
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 23 2014 Petr Machata <pmachata@redhat.com> - 0.8.0.2-27
- Rebuild for boost 1.55.0

* Fri May 23 2014 Petr Machata <pmachata@redhat.com> - 0.8.0.2-26
- Rebuild for boost 1.55.0

* Fri May 23 2014 David Tardon <dtardon@redhat.com> - 0.8.0.2-25
- rebuild for boost 1.55.0

* Fri Apr 04 2014 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.8.0.2-24
- Rebuild for ImageMagick-6.8.8.

* Wed Nov 27 2013 Rex Dieter <rdieter@fedoraproject.org> - 0.8.0.2-23
- rebuild (openexr)

* Thu Oct 10 2013 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.8.0.2-22
- Fix bogus %%changelog entry.

* Thu Oct 10 2013 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.8.0.2-21
- Rebuild for ImageMagick-6.8.7.

* Mon Sep 09 2013 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.8.0.2-20
- Rebuild for ilmbase-2.0.1.

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.0.2-19
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sat Jul 27 2013 pmachata@redhat.com - 0.8.0.2-18
- Rebuild for boost 1.54.0

* Thu Mar 21 2013 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.8.0.2-17
- Rebuild for ImageMagick-6.8.3.9.

* Sun Mar 10 2013 Rex Dieter <rdieter@fedoraproject.org> - 0.8.0.2-16
- rebuild (OpenEXR)

* Sun Feb 10 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.8.0.2-15
- Rebuild for Boost-1.53.0

* Sat Feb 09 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.8.0.2-14
- Rebuild for Boost-1.53.0

* Fri Jan 18 2013 Adam Tkac <atkac redhat com> - 0.8.0.2-13
- rebuild due to "jpeg8-ABI" feature drop

* Fri Dec 21 2012 Adam Tkac <atkac redhat com> - 0.8.0.2-12
- rebuild against new libjpeg

* Sun Aug 12 2012 Kevin Fenzi <kevin@scrye.com> - 0.8.0.2-11
- Rebuilt for new boost

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.0.2-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Mon May 07 2012 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.8.0.2-9
- Rebuilt for libtiff-4.0.

* Thu Apr 12 2012 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.8.0.2-8
- Rebuilt for ImageMagick.

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.0.2-7
- Rebuilt for c++ ABI breakage

* Thu Jan 05 2012 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.8.0.2-6
- Add k3d-0.8.0.2-gcc-4.7.patch (Address gcc-4.7 FTBS).

* Mon Nov 28 2011 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.8.0.2-5
- Add k3d-0.8.0.2-libpng1.4.patch (Work-around libpng-1.4 incompatibilities).
- Rebuild for libpng-1.4.

* Thu Jul 21 2011 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.8.0.2-4
- Rebuild for boost-1.47.

* Tue May 10 2011 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.8.0.2-3
- Add k3d-0.8.0.2-gtkmm2.24.diff (Address FTBS caused by gtkmm24 incompatiblity).
- Modernize spec.

* Thu Feb 10 2011 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.8.0.2-2
- Remove obsolete Obsoletes: k3d-examples.

* Thu Feb 10 2011 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.8.0.2-1
- Upstream update (contains boost-compatibility fixes).
- Add k3d-0.8.0.2-gcc-4.6.diff (Work around g++ mutable changes).
- Add k3d-0.8.0.2-cmake.diff (Work around cmake not getting libdir right).
- Reflect upstream having switched to using versoned libs.

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.0.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Sep 29 2010 jkeating - 0.8.0.1-4
- Rebuilt for gcc bug 634757

* Thu Sep 16 2010 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.8.0.1-3
- Rebuilt for libImageMagick.so.4.

* Tue Jul 27 2010 David Malcolm <dmalcolm@redhat.com> - 0.8.0.1-2
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Fri May 14 2010 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.8.0.1-1
- Upstream update.

* Mon Mar 08 2010 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.7.11.0-7
- Rebuild for ImageMagick SONAME change.

* Tue Feb 09 2010 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.7.11.0-6
- Add BR: pkgconfig(uuid).
- Remove BR: libuuid-devel, libgnome-devel, graphviz-devel.
- Remove broken fontdir removal.

* Tue Feb 09 2010 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.7.11.0-5
- Switch back to using to using libuuid (Remove k3d-0.7.11.0-ossp-uuid.patch).
- Remove BR: e2fsprogs-devel, librsvg2, libsigc++20-devel, libpng-devel.

* Tue Feb 09 2010 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.7.11.0-4
- Rebase uuid-generation against ossp-uuid (Address FTBS BZ #539048).
- Misc. spec-file clean up.
- Move %%{_libdir}/*.so into base-package (BZ #513773).
- Move %%{_libdir}/k3d/include into devel-package.
- Move %%{_datadir}/k3d/shaders/*.h into devel-package.

* Fri Jan 22 2010 Rahul Sundaram <sundaram@fedoraproject.org> - 0.7.11.0-3
- Rebuild for Boost soname bump

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.11.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sun Mar 22 2009 Denis Leroy <denis@poolshark.org> - 0.7.11.0-1
- Update to upstream 0.7.11.0

* Wed Mar  4 2009 Denis Leroy <denis@poolshark.org> - 0.7.10.0-1
- Update to upstream 0.7.10.0
- Build system now based on cmake
- All patches upstreamed or obsoleted
- Added potfiles file list patch fix
- Removed example subpackage
- Removed packaged bitstream fonts, use Fedora ones instead

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.7.0-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Dec 18 2008 Petr Machata <pmachata@redhat.com> - 0.6.7.0-9
- Rebuild for new boost

* Sun Nov 30 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 0.6.7.0-8
- Rebuild for Python 2.6

* Fri May 16 2008 Denis Leroy <denis@poolshark.org> - 0.6.7.0-7
- Rebuild for new ImageMagick

* Tue Apr  1 2008 Denis Leroy <denis@poolshark.org> - 0.6.7.0-6
- Added patch to fix sigc++ include headers

* Sat Feb 16 2008 Denis Leroy <denis@poolshark.org> - 0.6.7.0-5
- Added patch for gcc 4.3 rebuild

* Mon Oct 15 2007 Denis Leroy <denis@poolshark.org> - 0.6.7.0-4
- Rebuild for OpenEXR 1.6

* Tue Aug 28 2007 Denis Leroy <denis@poolshark.org> - 0.6.7.0-3
- Rebuild for expat 2.0

* Sat Aug  4 2007 Denis Leroy <denis@poolshark.localdomain> - 0.6.7.0-2
- Rebuild for newer boost library

* Mon Jul  9 2007 Denis Leroy <denis@poolshark.org> - 0.6.7.0-1
- Update to 0.6.7.0
- Removed patches that moved upstream
- Added gnome-vfs2-devel, fixed gnome-vfs2 missing config
- Fixed lib64 script to avoid autoreconf
- Added aqsis dependency
- Removed MultipleArgs from desktop file

* Fri Dec 29 2006 Denis Leroy <denis@poolshark.org> - 0.6.5.0-1
- Update to 0.6.5.0
- Added patch to fix x86_64 startup crash in viewport widget
- Added patch to fix python 2.5 API changes

* Mon Dec 11 2006 Denis Leroy <denis@poolshark.org> - 0.6.4.0-2
- Rebuild with python 2.5

* Thu Nov 23 2006 Denis Leroy <denis@poolshark.org> - 0.6.4.0-1
- Update to 0.6.4.0

* Tue Oct 10 2006 Denis Leroy <denis@poolshark.org> - 0.6.3.1-1
- Update to 0.6.3.1

* Mon Oct  9 2006 Denis Leroy <denis@poolshark.org> - 0.6.3.0-1
- Update to 0.6.3.0

* Thu Oct 05 2006 Christian Iseli <Christian.Iseli@licr.org> 0.6.2.0-2
 - rebuilt for unwind info generation, broken in gcc-4.1.1-21

* Sun Sep 24 2006 Denis Leroy <denis@poolshark.org> - 0.6.2.0-1
- Update to 0.6.2.0

* Mon Sep 11 2006 Denis Leroy <denis@poolshark.org> - 0.6.1.0-2
- Rebuild against new OpenEXR version

* Wed Sep  6 2006 Denis Leroy <denis@poolshark.org> - 0.6.1.0-1
- Update to 0.6.1.0

* Mon Aug 28 2006 Denis Leroy <denis@poolshark.org> - 0.6.0.0-2
- FE6 Rebuild

* Wed Aug 23 2006 Denis Leroy <denis@poolshark.org> - 0.6.0.0-1
- Update to 0.6.0.0
- Split example documents into separate package

* Fri Aug 11 2006 Denis Leroy <denis@poolshark.org> - 0.5.16.0-3
- Added sample_document to devel pkg

* Thu Aug 10 2006 Denis Leroy <denis@poolshark.org> - 0.5.16.0-2
- Added ChangeLog to devel doc

* Sat Aug  5 2006 Denis Leroy <denis@poolshark.org> - 0.5.16.0-1
- Update to version 0.5.16.0

* Tue Aug  1 2006 Denis Leroy <denis@poolshark.org> - 0.5.15.0-3
- Recreated devel package

* Tue Aug  1 2006 Denis Leroy <denis@poolshark.org> - 0.5.15.0-2
- Cleaned up files sections

* Tue Jul 25 2006 root <denis@poolshark.org> - 0.5.15.0-1
- Update to 0.5.15.0
- Added patch to detect opengl correctly on x86_64

* Tue Mar  7 2006 Denis Leroy <denis@poolshark.org> - 0.5.0.39-1
- First version
